%bcond_without check

# A daemon that manages a pool of block devices to create flexible filesystems
%global __cargo_is_lib() false
%global udevdir %(pkg-config --variable=udevdir udev)

Name:           stratisd
Version:        2.3.0
Release:        2%{?dist}
Summary:        Daemon that manages block devices to create filesystems

License:        MPLv2.0
URL:            https://github.com/stratis-storage/stratisd
Source0:        %{url}/archive/v%{version}/%{name}-%{version}.tar.gz
Source1:        %{name}-%{version}-vendor.tar.xz

ExclusiveArch:  %{rust_arches}
ExcludeArch:    i686
BuildRequires:  rust-toolset
BuildRequires:  systemd-devel
BuildRequires:  dbus-devel
BuildRequires:  libblkid-devel
BuildRequires:  cryptsetup-devel
BuildRequires:  clang
BuildRequires:  %{_bindir}/a2x

Requires:       xfsprogs
Requires:       device-mapper-persistent-data
Requires:       systemd-libs
Requires:       dbus-libs
Requires:       cryptsetup >= 2.3.0
Requires:       clevis-luks >= 15

%description
%{summary}.

%prep
%setup -q -n %{name}-%{version}

# Source1 is vendored dependencies
%cargo_prep -V 1

%build
%cargo_build
a2x -f manpage docs/stratisd.txt

%install
%cargo_install
%{__install} -Dpm0644 -t %{buildroot}%{_datadir}/dbus-1/system.d stratisd.conf
# Daemon should be really private
mkdir -p %{buildroot}%{_libexecdir}
mkdir -p %{buildroot}%{udevdir}
mkdir -p %{buildroot}/developer_tools
mv %{buildroot}%{_bindir}/stratisd %{buildroot}%{_libexecdir}/stratisd
mv %{buildroot}%{_bindir}/stratis_uuids_to_names %{buildroot}%{udevdir}/stratis_uuids_to_names
%{__install} -Dpm0644 -t %{buildroot}%{_mandir}/man8 docs/stratisd.8
%{__install} -Dpm0644 -t %{buildroot}%{_udevrulesdir} udev/11-stratisd.rules
%{__install} -Dpm0644 -t %{buildroot}%{_unitdir} stratisd.service
%{__install} -Dpm0755 -t %{buildroot}%{_bindir} developer_tools/stratis_migrate_symlinks.sh

%if %{with check}
%check
%cargo_test -- --skip real_ --skip loop_ --skip travis_
%endif

%post
%systemd_post stratisd.service

%preun
%systemd_preun stratisd.service

%postun
%systemd_postun_with_restart stratisd.service

%files
%license LICENSE
%doc README.md
%{_libexecdir}/stratisd
%{udevdir}/stratis_uuids_to_names
%{_bindir}/stratis_dbusquery_version
%{_bindir}/stratis_migrate_symlinks.sh
%dir %{_datadir}/dbus-1
%{_datadir}/dbus-1/system.d/stratisd.conf
%{_mandir}/man8/stratisd.8*
%{_unitdir}/stratisd.service
%config %{_udevrulesdir}/11-stratisd.rules

%changelog
* Tue Dec 08 2020  Dennis Keefe <dkeefe@redhat.com> - 2.3.0-2
- Update to 2.3.0
- Resolves: rhbz#1885328
- Stratis devices inhabit an existing root directory path
- Resolves: rhbz#1798244
- Add Clevis Support
- Resolves: rhbz#1868100
- Improve stratisd log levels
- Resolves: rhbz#1757976
 
* Sat Jun 06 2020  Dennis Keefe <dkeefe@redhat.com> - 2.1.0-1
- Update to 2.1.0
- Resolves: rhbz#1791473
- Update Stratis RPM Spec File
- Resolves: rhbz#1828487
- Support per-pool encryption of the devices that form a pool's data tier
- Resolves: rhbz#1768580
- Improve systemd unit file description
- Resolves: rhbz#1756525

* Tue Nov 12 2019  Dennis Keefe <dkeefe@redhat.com> - 2.0.0-4
- Update to 2.0.0
- Resolves: rhbz#1760906
- Fix a bug where last update time for variable length metadata was not set
  properly on startup:
- Resolves: rhbz#1720399
- Specify path of PID file as "/run/stratisd.pid" instead of 
  "/var/run/stratisd.pid".
- Resolves: rhbz#1754649
- For a particular log entry, reduce log level from INFO to DEBUG and make the
  log message more detailed:
- Resolves: rhbz#1680052
 
* Mon Jun 3 2019 Dennis Keefe <dkeefe@redhat.com> - 1.0.4-2
- update to 1.0.4

* Wed Jan 9 2019 Andy Grover <agrover@redhat.com> - 1.0.3-1
- Update to 1.0.3

* Tue Dec 11 2018 Andy Grover <agrover@redhat.com> - 1.0.2-1
- Update to 1.0.2

* Tue Nov 6 2018 Andy Grover <agrover@redhat.com> - 1.0.1-1
- Update to 1.0.1

* Mon Oct 8 2018 Andy Grover <agrover@redhat.com> - 1.0.0-2
- Fix for non-Dbus activation

* Tue Oct 2 2018 Andy Grover <agrover@redhat.com> - 1.0.0-1
- Update to 1.0.0

* Wed Aug 08 2018 Josh Stone <jistone@redhat.com> - 0.5.5-2
- Rebuild with rust-toolset-1.26

* Thu Aug 2 2018 Andy Grover <agrover@redhat.com> - 0.5.5-1
- Update to 0.5.5

* Fri Jul 13 2018 Andy Grover <agrover@redhat.com> - 0.5.4-1
- Update to 0.5.4

* Thu May 24 2018 Andy Grover <agrover@redhat.com> - 0.5.2-1
- Initial packaging for RHEL 8
- Update to 0.5.2
